import type { Theme } from "../types";

export const lightTheme: Theme = {
  // Background and base text
  background: "#ffffff",
  text: "#24292f",
  
  // Core syntax elements
  keyword: "#cf222e",     // Bright red for better visibility
  string: "#0a3069",      // Deeper blue for strings
  number: "#0550ae",      // Bright blue for numbers
  boolean: "#0550ae",     // Same as numbers for consistency
  null: "#0550ae",        // Same as boolean/numbers
  undefined: "#0550ae",   // Same as null
  
  // Operators and punctuation
  operator: "#cf222e",    // Same as keywords for consistency
  punctuation: "#24292f", // Same as base text
  
  // Code structure
  identifier: "#24292f",  // Base text color
  function: "#8250df",    // Purple for functions
  class: "#116329",       // Green for classes/types
  builtin: "#0550ae",     // Same as numbers for built-ins
  
  // Secondary elements
  variable: "#953800",    // Orange for variables
  property: "#0550ae",    // Same as built-ins
  decorator: "#8250df",   // Same as functions
  regex: "#116329",       // Same as classes
  
  // Comments and UI
  comment: "#6e7781",     // Subtle gray
  lineNumber: "#8c959f",  // Slightly darker than comments
};

export const darkTheme: Theme = {
  // Background and base text
  background: "#1f2937", // Slightly lighter than pure black
  text: "#e5e7eb",      // Off-white for better contrast
  
  // Core syntax elements
  keyword: "#f47067",   // Soft red
  string: "#96d0ff",    // Light blue
  number: "#79c0ff",    // Bright blue
  boolean: "#79c0ff",   // Same as numbers
  null: "#79c0ff",      // Same as boolean
  undefined: "#79c0ff", // Same as null
  
  // Operators and punctuation
  operator: "#f47067",  // Same as keywords
  punctuation: "#e5e7eb", // Same as base text
  
  // Code structure
  identifier: "#e5e7eb", // Base text color
  function: "#d2a8ff",   // Light purple
  class: "#7ee787",      // Light green
  builtin: "#79c0ff",    // Same as numbers
  
  // Secondary elements
  variable: "#ffa657",   // Orange
  property: "#79c0ff",   // Same as built-ins
  decorator: "#d2a8ff",  // Same as functions
  regex: "#7ee787",      // Same as classes
  
  // Comments and UI
  comment: "#8b949e",    // Medium gray
  lineNumber: "#6e7681", // Darker gray for line numbers
};

export const themes = {
  light: lightTheme,
  dark: darkTheme,
};
